@@ -250,6 +250,16 @@ extern const lookup_info ml_table_signal_run_type[];
 #define Val_signal_run_type(data) ml_lookup_from_c (ml_table_signal_run_type, data)
 #define Signal_run_type_val(key) ml_lookup_to_c (ml_table_signal_run_type, key)
 
+/* scroll_step : tags and macros */
+#define MLTAG_STEPS	((value)(33338247*2+1))
+#define MLTAG_HORIZONTAL_STEPS	((value)(-897372500*2+1))
+#define MLTAG_HORIZONTAL_PAGES	((value)(63037001*2+1))
+#define MLTAG_HORIZONTAL_ENDS	((value)(331551923*2+1))
+
+extern const lookup_info ml_table_scroll_step[];
+#define Val_scroll_step(data) ml_lookup_from_c (ml_table_scroll_step, data)
+#define Scroll_step_val(key) ml_lookup_to_c (ml_table_scroll_step, key)
+
 /* scroll_type : tags and macros */
 #define MLTAG_JUMP	((value)(824872174*2+1))
 #define MLTAG_STEP_FORWARD	((value)(-119149966*2+1))
